#include "Constants.h"
#include "Io.h"
#include "Keyboard.h"
#include "Kempston.h"
#include "DataBus.h"
#include "ULABus.h"
#include "Sound.h"

Uint8 _borderColour;
Uint8 _isSpeakerActive;

void io_start() {
	io_destroy();
}

void io_destroy() {
	_isSpeakerActive = 0;
}

Uint8 io_read8_16bitaddr(Uint16 port) {
	// joystick takes precedence over keyboard
	if (kempston_is_supported_address(port)) {
		Uint8 value = kempston_read8(port);
		data_bus_write8(value);
		return value;
	}

	if (keyboard_is_supported_address(port)) {
		Uint8 value = keyboard_read8(port);
		data_bus_write8(value);
		return value;
	}

	if (ula_bus_is_supported_address(port)) {
		Uint8 value = ula_bus_read8(port);
		return value;
	}

	return 0xff;
}

void io_write8_16bitaddr(Uint16 port, Uint8 value) {
	data_bus_write8(value);

	switch (port & 0x00FF) {
	case PORT_BORDER_COLOUR:
		_borderColour = value;
		Uint8 speaker = value & 0x10;	// keep only bit 4
		if (_isSpeakerActive != speaker) {
			// experimental... enabling this makes some sounds that otherwise wouldn't be heard
			//                 (probably because they're too short to be sampled)
			//                 BUT it also decresease the frequency of each sound (since it increases
			//                 sustain time artificially by one sample)
			//sound_add_sample_forced(speaker);
		}
		_isSpeakerActive = speaker;
		break;
	default:
		break;
	}
}

Uint8 io_read8_border_colour() {
	return _borderColour;
}

Uint8 io_is_speaker_active() {
	return _isSpeakerActive;
}
